You are viewing a plain text version of this content. The canonical link for it is here.
Posted to java-dev@axis.apache.org by as...@apache.org on 2005/08/16 16:33:23 UTC

svn commit: r233000 - in /webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws: ./ src/org/apache/axis2/jaxws/client/ src/org/apache/axis2/jaxws/description/ src/org/apache/axis2/jaxws/handler/ src/org/apache/axis2/jaxws/handler/soap/ src...

Author: ashutosh
Date: Tue Aug 16 07:32:44 2005
New Revision: 233000

URL: http://svn.apache.org/viewcvs?rev=233000&view=rev
Log: (empty)

Modified:
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/.classpath
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/client/BindingImpl.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/client/BindingProviderImpl.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/client/CallImpl.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/client/DispatchImpl.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/client/JAXRPCContextImpl.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/client/JAXRPCRequestContext.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/client/JAXRPCResponseContext.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/client/ServiceFactoryImpl.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/client/ServiceImpl.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/description/ParameterDesc.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/handler/Axis2Handler.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/handler/HandlerChainImpl.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/handler/MessageContextImpl.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/handler/soap/SOAPMessageContextImpl.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/server/ServletEndpointContextImpl.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/soap/SOAPBindingImpl.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/test/org/apache/axis2/jaxws/ServiceFactoryTest.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/test/org/apache/axis2/jaxws/client/CallTesting.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/test/org/apache/axis2/jaxws/handler/soap/ClientWithLoggingHandler.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/test/org/apache/axis2/jaxws/handler/soap/LoggingHandler.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/test/org/apache/axis2/jaxws/integrationTesting/ClientAPITest1.java
    webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/test/org/apache/axis2/jaxws/server/ServerTestingPurposeClient.java

Modified: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/.classpath
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/.classpath?rev=233000&r1=232999&r2=233000&view=diff
==============================================================================
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/.classpath (original)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/.classpath Tue Aug 16 07:32:44 2005
@@ -1,9 +1,9 @@
 <?xml version="1.0" encoding="UTF-8"?>
 <classpath>
 	<classpathentry kind="src" path="src"/>
-	<classpathentry output="target/test-classes" kind="src" path="test"/>
+	<classpathentry kind="src" path="test"/>
 	<classpathentry kind="var" path="MAVEN_REPO/junit/jars/junit-3.8.1.jar"/>
-	<classpathentry kind="con" path="org.eclipse.jdt.launching.JRE_CONTAINER/org.eclipse.jdt.internal.debug.ui.launcher.StandardVMType/jre1.5.0"/>
+	<classpathentry kind="con" path="org.eclipse.jdt.launching.JRE_CONTAINER"/>
 	<classpathentry kind="var" path="MAVEN_REPO/jaxb/jars/jaxb-api-0.5.jar"/>
 	<classpathentry kind="var" path="MAVEN_REPO/axis/jars/axis2-xml-0.9.jar"/>
 	<classpathentry kind="var" path="MAVEN_REPO/axis/jars/saaj-impl-0.9.jar"/>

Modified: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/client/BindingImpl.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/client/BindingImpl.java?rev=233000&r1=232999&r2=233000&view=diff
==============================================================================
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/client/BindingImpl.java (original)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/client/BindingImpl.java Tue Aug 16 07:32:44 2005
@@ -2,10 +2,10 @@
 
 import java.util.List;
 
-import javax.xml.rpc.Binding;
-import javax.xml.rpc.JAXRPCException;
-import javax.xml.rpc.handler.HandlerInfo;
-import javax.xml.rpc.security.SecurityConfiguration;
+import javax.xml.ws.Binding;
+import javax.xml.ws.WebServiceException;
+import javax.xml.ws.handler.HandlerInfo;
+import javax.xml.ws.security.SecurityConfiguration;
 
 public class BindingImpl implements Binding {
 
@@ -14,7 +14,7 @@
 		return null;
 	}
 
-	public void setHandlerChain(List<HandlerInfo> chain) throws JAXRPCException {
+	public void setHandlerChain(List<HandlerInfo> chain) throws WebServiceException {
 		// TODO Auto-generated method stub
 
 	}

Modified: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/client/BindingProviderImpl.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/client/BindingProviderImpl.java?rev=233000&r1=232999&r2=233000&view=diff
==============================================================================
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/client/BindingProviderImpl.java (original)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/client/BindingProviderImpl.java Tue Aug 16 07:32:44 2005
@@ -21,10 +21,10 @@
 import java.util.Map;
 
 import javax.xml.namespace.QName;
-import javax.xml.rpc.Binding;
-import javax.xml.rpc.BindingProvider;
-import javax.xml.rpc.JAXRPCContext;
-import javax.xml.rpc.handler.HandlerInfo;
+import javax.xml.ws.Binding;
+import javax.xml.ws.BindingProvider;
+import javax.xml.ws.JAXRPCContext;
+import javax.xml.ws.handler.HandlerInfo;
 
 import org.apache.axis2.context.ServiceContext;
 import org.apache.axis2.engine.Phase;

Modified: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/client/CallImpl.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/client/CallImpl.java?rev=233000&r1=232999&r2=233000&view=diff
==============================================================================
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/client/JAXRPCContextImpl.java (original)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/client/JAXRPCContextImpl.java Tue Aug 16 07:32:44 2005
@@ -22,9 +22,9 @@
 import java.util.List;
 import java.util.Map;
 
-import javax.xml.rpc.BindingProvider;
-import javax.xml.rpc.JAXRPCContext;
-import javax.xml.rpc.JAXRPCException;
+import javax.xml.ws.BindingProvider;
+import javax.xml.ws.JAXRPCContext;
+import javax.xml.ws.WebServiceException;
 
 import org.apache.axis2.context.ConfigurationContext;
 import org.apache.axis2.engine.AxisConfiguration;
@@ -77,9 +77,9 @@
 	
 	private void validateProperty(String name, Object value){
 		if(name == null)
-			throw new JAXRPCException("User-defined property name can not be null");
+			throw new WebServiceException("User-defined property name can not be null");
 		if(standardProperties.indexOf(name) == -1 && name.startsWith("javax.xml.rpc"))
-			throw new JAXRPCException("User-Defined property can not start with javax.ml.rpc");
+			throw new WebServiceException("User-Defined property can not start with javax.ml.rpc");
 
 	}
 	/*

Modified: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/client/JAXRPCRequestContext.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/client/JAXRPCRequestContext.java?rev=233000&r1=232999&r2=233000&view=diff
==============================================================================
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/client/JAXRPCRequestContext.java (original)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/client/JAXRPCRequestContext.java Tue Aug 16 07:32:44 2005
@@ -16,7 +16,7 @@
 
 package org.apache.axis2.jaxws.client;
 
-import javax.xml.rpc.BindingProvider;
+import javax.xml.ws.BindingProvider;
 
 public class JAXRPCRequestContext extends JAXRPCContextImpl {
 	

Modified: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/client/JAXRPCResponseContext.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/client/JAXRPCResponseContext.java?rev=233000&r1=232999&r2=233000&view=diff
==============================================================================
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/client/JAXRPCResponseContext.java (original)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/client/JAXRPCResponseContext.java Tue Aug 16 07:32:44 2005
@@ -16,7 +16,7 @@
 
 package org.apache.axis2.jaxws.client;
 
-import javax.xml.rpc.BindingProvider;
+import javax.xml.ws.BindingProvider;
 
 public class JAXRPCResponseContext extends JAXRPCContextImpl {
 

Modified: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/client/ServiceFactoryImpl.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/client/ServiceFactoryImpl.java?rev=233000&r1=232999&r2=233000&view=diff
==============================================================================
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/client/ServiceFactoryImpl.java (original)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/client/ServiceFactoryImpl.java Tue Aug 16 07:32:44 2005
@@ -4,9 +4,9 @@
 import java.util.Properties;
 
 import javax.xml.namespace.QName;
-import javax.xml.rpc.Service;
-import javax.xml.rpc.ServiceException;
-import javax.xml.rpc.ServiceFactory;
+import javax.xml.ws.Service;
+import javax.xml.ws.ServiceException;
+import javax.xml.ws.ServiceFactory;
 
 import org.apache.axis2.jaxws.JAXRPCWSDLInterface;
 import org.apache.axis2.jaxws.factory.WSDLFactoryImpl;

Modified: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/client/ServiceImpl.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/client/ServiceImpl.java?rev=233000&r1=232999&r2=233000&view=diff
==============================================================================
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/client/ServiceImpl.java (original)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/client/ServiceImpl.java Tue Aug 16 07:32:44 2005
@@ -26,17 +26,17 @@
 
 import javax.xml.bind.JAXBContext;
 import javax.xml.namespace.QName;
-import javax.xml.rpc.Call;
-import javax.xml.rpc.Dispatch;
-import javax.xml.rpc.JAXRPCException;
-import javax.xml.rpc.ServiceException;
-import javax.xml.rpc.Stub;
-import javax.xml.rpc.Service.Mode;
 import javax.xml.rpc.encoding.TypeMappingRegistry;
-import javax.xml.rpc.handler.AbstractHandler;
-import javax.xml.rpc.handler.HandlerInfo;
-import javax.xml.rpc.handler.HandlerRegistry;
-import javax.xml.rpc.security.SecurityConfiguration;
+import javax.xml.ws.Call;
+import javax.xml.ws.Dispatch;
+import javax.xml.ws.WebServiceException;
+import javax.xml.ws.ServiceException;
+import javax.xml.ws.Stub;
+import javax.xml.ws.Service.Mode;
+import javax.xml.ws.handler.AbstractHandler;
+import javax.xml.ws.handler.HandlerInfo;
+import javax.xml.ws.handler.HandlerRegistry;
+import javax.xml.ws.security.SecurityConfiguration;
 
 import javax.wsdl.*;
 import javax.wsdl.extensions.ExtensibilityElement;
@@ -65,7 +65,7 @@
  * @author sunja07
  * Class ServiceImpl
  */
-public class ServiceImpl implements javax.xml.rpc.Service {
+public class ServiceImpl implements javax.xml.ws.Service {
 	
 	private HandlerRegistryImpl handlerRegistry = new HandlerRegistryImpl();
 	
@@ -209,7 +209,7 @@
 		}
 		
 		public void setHandlerChain(javax.xml.namespace.QName portName,
-				java.util.List chain) throws JAXRPCException, java.lang.UnsupportedOperationException,
+				java.util.List chain) throws WebServiceException, java.lang.UnsupportedOperationException,
 				java.lang.IllegalArgumentException{
 			
 			confirmPort(portName);
@@ -224,7 +224,7 @@
 			return serviceHandlerChain;
 		}
 		
-		public void setHandlerChain(java.util.List<HandlerInfo> chain) throws java.lang.UnsupportedOperationException, JAXRPCException{
+		public void setHandlerChain(java.util.List<HandlerInfo> chain) throws java.lang.UnsupportedOperationException, WebServiceException{
 			serviceHandlerChain = chain;
 		}
 		
@@ -239,7 +239,7 @@
 		}
 		
 		public void setHandlerChain(java.net.URI bindingId,
-				java.util.List<HandlerInfo> chain) throws JAXRPCException,
+				java.util.List<HandlerInfo> chain) throws WebServiceException,
 				java.lang.UnsupportedOperationException, java.lang.IllegalArgumentException{
 			
 			confirmBindingId(bindingId);
@@ -408,7 +408,7 @@
 	 * @param bindingId A URI identifier of a binding.
 	 * @param endpointAddress Address of the target service endpoint as a URI 
 	 * @throws ServiceException If any error in the creation of the port
-	 * @see javax.xml.rpc.soap.SOAPBinding.SOAP11HTTP_BINDING
+	 * @see javax.xml.ws.soap.SOAPBinding.SOAP11HTTP_BINDING
 	 */
 	public void createPort(QName portName, URI bindingId, 
 			String endpointAddress) throws ServiceException {

Modified: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/description/ParameterDesc.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/description/ParameterDesc.java?rev=233000&r1=232999&r2=233000&view=diff
==============================================================================
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/description/ParameterDesc.java (original)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/description/ParameterDesc.java Tue Aug 16 07:32:44 2005
@@ -1,6 +1,6 @@
 package org.apache.axis2.jaxws.description;
 
-import javax.xml.rpc.ParameterMode;
+import javax.xml.ws.ParameterMode;
 import javax.xml.namespace.QName;
 
 public class ParameterDesc {

Modified: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/handler/Axis2Handler.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/handler/Axis2Handler.java?rev=233000&r1=232999&r2=233000&view=diff
==============================================================================
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/handler/Axis2Handler.java (original)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/handler/Axis2Handler.java Tue Aug 16 07:32:44 2005
@@ -7,21 +7,21 @@
 
 public class Axis2Handler extends AbstractHandler {
 	
-	private javax.xml.rpc.handler.AbstractHandler jaxRpcHandler;
+	private javax.xml.ws.handler.AbstractHandler jaxRpcHandler;
 	
 	public Axis2Handler(){
 		//Default constructor, jaxRpcHandler will be set through setter method
 	}
 	
-	public Axis2Handler(javax.xml.rpc.handler.AbstractHandler jaxRpcHandler){
+	public Axis2Handler(javax.xml.ws.handler.AbstractHandler jaxRpcHandler){
 		this.jaxRpcHandler = jaxRpcHandler;
 	}
 	
-	public void setJaxRpcHandler(javax.xml.rpc.handler.AbstractHandler handler){
+	public void setJaxRpcHandler(javax.xml.ws.handler.AbstractHandler handler){
 		jaxRpcHandler = handler;
 	}
 	
-	public javax.xml.rpc.handler.AbstractHandler getJaxRpcHandler(){
+	public javax.xml.ws.handler.AbstractHandler getJaxRpcHandler(){
 		return jaxRpcHandler;
 	}
 

Modified: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/handler/HandlerChainImpl.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/handler/HandlerChainImpl.java?rev=233000&r1=232999&r2=233000&view=diff
==============================================================================
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/handler/HandlerChainImpl.java (original)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/handler/HandlerChainImpl.java Tue Aug 16 07:32:44 2005
@@ -5,16 +5,16 @@
 import java.util.Map;
 import java.util.Arrays;
 
-import javax.xml.rpc.JAXRPCException;
-import javax.xml.rpc.handler.Handler;
-import javax.xml.rpc.handler.HandlerChain;
-import javax.xml.rpc.handler.HandlerInfo;
-import javax.xml.rpc.handler.MessageContext;
-import javax.xml.rpc.handler.soap.SOAPMessageContext;
 import javax.xml.soap.SOAPBody;
 import javax.xml.soap.SOAPElement;
 import javax.xml.soap.SOAPEnvelope;
 import javax.xml.soap.SOAPMessage;
+import javax.xml.ws.WebServiceException;
+import javax.xml.ws.handler.Handler;
+import javax.xml.ws.handler.HandlerChain;
+import javax.xml.ws.handler.HandlerInfo;
+import javax.xml.ws.handler.MessageContext;
+import javax.xml.ws.handler.soap.SOAPMessageContext;
 
 import org.apache.axis2.jaxws.handler.soap.SOAPMessageContextImpl;
 import org.apache.axis2.jaxws.handler.MessageContextImpl;
@@ -45,7 +45,7 @@
 			handler.init(handlerInfo);
 			return handler;
 		} catch (Exception ex){
-			throw new JAXRPCException("No Jax-RPC handler" + handlerInfo.getHandlerClass().toString(), ex);
+			throw new WebServiceException("No Jax-RPC handler" + handlerInfo.getHandlerClass().toString(), ex);
 		}
 	}
 	
@@ -80,7 +80,7 @@
 			handlerInfos.add(handlerInfo);
 			add(newHandler(handlerInfo));
 		} catch(Exception ex){
-			throw new JAXRPCException("No Jax-RPC handler"+className, ex);
+			throw new WebServiceException("No Jax-RPC handler"+className, ex);
 		}
 	}
 	
@@ -104,7 +104,7 @@
 		return list;
 	}
 	
-	public boolean handleRequest(MessageContext _context) throws JAXRPCException {
+	public boolean handleRequest(MessageContext _context) throws WebServiceException {
 		SOAPMessageContextImpl actx = (SOAPMessageContextImpl)_context;
 		actx.setRoles(getRoles());
 		SOAPMessageContext context = (SOAPMessageContext)_context;
@@ -117,7 +117,7 @@
 						falseIndex = i;
 						return false;
 					}
-				}catch (javax.xml.rpc.soap.SOAPFaultException sfe) {
+				}catch (javax.xml.ws.soap.SOAPFaultException sfe) {
 					falseIndex = i;
 					throw sfe;
 				}
@@ -129,7 +129,7 @@
 	}
 
 	public boolean handleResponse(MessageContext context)
-			throws JAXRPCException {
+			throws WebServiceException {
 		SOAPMessageContextImpl scontext = (SOAPMessageContextImpl)context;
 		preInvoke(scontext);
 		try {
@@ -148,7 +148,7 @@
 		}
 	}
 
-	public boolean handleFault(MessageContext _context) throws JAXRPCException {
+	public boolean handleFault(MessageContext _context) throws WebServiceException {
 		SOAPMessageContextImpl context = (SOAPMessageContextImpl)_context;
 		preInvoke(context);
 		try {
@@ -167,11 +167,11 @@
 		}
 	}
 
-	public void init(Map config) throws JAXRPCException {
+	public void init(Map config) throws WebServiceException {
 		// DO SOMETHING WITH THIS
 	}
 
-	public void destroy() throws JAXRPCException {
+	public void destroy() throws WebServiceException {
 		int endIdx = size() - 1;
 		if (falseIndex != -1) {
 			endIdx = falseIndex;

Modified: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/handler/MessageContextImpl.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/handler/MessageContextImpl.java?rev=233000&r1=232999&r2=233000&view=diff
==============================================================================
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/handler/MessageContextImpl.java (original)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/handler/MessageContextImpl.java Tue Aug 16 07:32:44 2005
@@ -3,7 +3,7 @@
 import java.util.HashMap;
 import java.util.Iterator;
 
-import javax.xml.rpc.handler.MessageContext;
+import javax.xml.ws.handler.MessageContext;
 
 public class MessageContextImpl implements MessageContext {
 	

Modified: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/handler/soap/SOAPMessageContextImpl.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/handler/soap/SOAPMessageContextImpl.java?rev=233000&r1=232999&r2=233000&view=diff
==============================================================================
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/handler/soap/SOAPMessageContextImpl.java (original)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/handler/soap/SOAPMessageContextImpl.java Tue Aug 16 07:32:44 2005
@@ -4,9 +4,9 @@
 
 import javax.xml.bind.JAXBContext;
 import javax.xml.namespace.QName;
-import javax.xml.rpc.JAXRPCException;
-import javax.xml.rpc.handler.soap.SOAPMessageContext;
 import javax.xml.soap.SOAPMessage;
+import javax.xml.ws.WebServiceException;
+import javax.xml.ws.handler.soap.SOAPMessageContext;
 
 import org.apache.axis2.jaxws.handler.MessageContextImpl;
 
@@ -35,19 +35,19 @@
 		return new org.apache.axis2.saaj.SOAPMessageImpl(env);
 	}
 
-	public void setMessage(SOAPMessage message) throws JAXRPCException,
+	public void setMessage(SOAPMessage message) throws WebServiceException,
 			UnsupportedOperationException {
 		try{
 			axisMC.setEnvelope(((org.apache.axis2.saaj.SOAPEnvelopeImpl)(message.getSOAPPart().getEnvelope())).getOMEnvelope());
 		} catch(javax.xml.soap.SOAPException e){
-			throw new JAXRPCException(e);
+			throw new WebServiceException(e);
 		} catch(org.apache.axis2.AxisFault af){
-			throw new JAXRPCException(af);
+			throw new WebServiceException(af);
 		}
 	}
 
 	public Object[] getHeaders(QName header, JAXBContext context,
-			boolean allRoles) throws JAXRPCException {
+			boolean allRoles) throws WebServiceException {
 		// TODO 
 		return null;
 	}

Modified: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/server/ServletEndpointContextImpl.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/server/ServletEndpointContextImpl.java?rev=233000&r1=232999&r2=233000&view=diff
==============================================================================
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/soap/SOAPBindingImpl.java (original)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/soap/SOAPBindingImpl.java Tue Aug 16 07:32:44 2005
@@ -8,8 +8,8 @@
 import java.util.Set;
 import java.util.HashSet;
 
-import javax.xml.rpc.JAXRPCException;
-import javax.xml.rpc.soap.SOAPBinding;
+import javax.xml.ws.WebServiceException;
+import javax.xml.ws.soap.SOAPBinding;
 
 import org.apache.axis2.jaxws.client.BindingImpl;
 /**
@@ -25,7 +25,7 @@
 	/**
 	 * Empty Costructor
 	 */
-	public SOAPBindingImpl(String thisBinding) throws JAXRPCException{
+	public SOAPBindingImpl(String thisBinding) throws WebServiceException{
 		super();
 		setBinding(thisBinding);
 		try {
@@ -44,10 +44,10 @@
 				//setting the 'ultimate receiver' role
 				roles.add(new URI("http://www.w3.org/2003/05/soap-envelope/role/ultimateReceiver"));
 			} else
-				throw new JAXRPCException("Unsupported Binding URI!");
+				throw new WebServiceException("Unsupported Binding URI!");
 			
 		} catch (Exception e) {
-			throw new JAXRPCException(e);
+			throw new WebServiceException(e);
 		}
 	}
 
@@ -67,21 +67,21 @@
      * Sets the roles played by the SOAP binding instance.
      *
      * @param roles - The set of roles played by the binding instance.
-     * @throws JAXRPCException - On an error in the configuration of the 
+     * @throws WebServiceException - On an error in the configuration of the 
      * list of roles.
      */
-	public void setRoles(Set<URI> inputRoles) throws JAXRPCException {
+	public void setRoles(Set<URI> inputRoles) throws WebServiceException {
 		//iterate to see if any of the listed roles in 'none' role.
 		//if so, JAXRPC doesn't allow it.
 		try {
 			boolean isNone = inputRoles.contains(
 					new URI("http://www.w3.org/2003/05/soap-envelope/role/none"));
 			if(isNone) {
-				throw new JAXRPCException("none role not allowed!");
+				throw new WebServiceException("none role not allowed!");
 			}
 			roles.add(inputRoles);
 		} catch (URISyntaxException e) {
-			throw new JAXRPCException(e);
+			throw new WebServiceException(e);
 		}
 	}
 	

Modified: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/test/org/apache/axis2/jaxws/ServiceFactoryTest.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/test/org/apache/axis2/jaxws/ServiceFactoryTest.java?rev=233000&r1=232999&r2=233000&view=diff
==============================================================================
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/test/org/apache/axis2/jaxws/ServiceFactoryTest.java (original)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/test/org/apache/axis2/jaxws/ServiceFactoryTest.java Tue Aug 16 07:32:44 2005
@@ -2,8 +2,8 @@
 
 import junit.framework.TestCase;
 
-import javax.xml.rpc.ServiceFactory;
-import javax.xml.rpc.Service;
+import javax.xml.ws.Service;
+import javax.xml.ws.ServiceFactory;
 import javax.xml.namespace.QName;
 
 public class ServiceFactoryTest extends TestCase {

Modified: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/test/org/apache/axis2/jaxws/client/CallTesting.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/test/org/apache/axis2/jaxws/client/CallTesting.java?rev=233000&r1=232999&r2=233000&view=diff
==============================================================================
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/test/org/apache/axis2/jaxws/client/CallTesting.java (original)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/test/org/apache/axis2/jaxws/client/CallTesting.java Tue Aug 16 07:32:44 2005
@@ -10,11 +10,11 @@
 import java.util.List;
 
 import javax.xml.namespace.QName;
-import javax.xml.rpc.Call;
-import javax.xml.rpc.Service;
-import javax.xml.rpc.ParameterMode;
-import javax.xml.rpc.handler.HandlerInfo;
-import javax.xml.rpc.handler.HandlerRegistry;
+import javax.xml.ws.Call;
+import javax.xml.ws.ParameterMode;
+import javax.xml.ws.Service;
+import javax.xml.ws.handler.HandlerInfo;
+import javax.xml.ws.handler.HandlerRegistry;
 //import javax.xml.rpc.ServiceFactory;
 
 import org.apache.axis2.jaxws.client.ServiceImpl;

Modified: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/test/org/apache/axis2/jaxws/handler/soap/ClientWithLoggingHandler.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/test/org/apache/axis2/jaxws/handler/soap/ClientWithLoggingHandler.java?rev=233000&r1=232999&r2=233000&view=diff
==============================================================================
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/test/org/apache/axis2/jaxws/handler/soap/ClientWithLoggingHandler.java (original)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/test/org/apache/axis2/jaxws/handler/soap/ClientWithLoggingHandler.java Tue Aug 16 07:32:44 2005
@@ -10,11 +10,11 @@
 import java.util.List;
 
 import javax.xml.namespace.QName;
-import javax.xml.rpc.Call;
-import javax.xml.rpc.Service;
-import javax.xml.rpc.ParameterMode;
-import javax.xml.rpc.handler.HandlerInfo;
-import javax.xml.rpc.handler.HandlerRegistry;
+import javax.xml.ws.Call;
+import javax.xml.ws.ParameterMode;
+import javax.xml.ws.Service;
+import javax.xml.ws.handler.HandlerInfo;
+import javax.xml.ws.handler.HandlerRegistry;
 //import javax.xml.rpc.ServiceFactory;
 
 import org.apache.axis2.jaxws.client.BindingProviderImpl;

Modified: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/test/org/apache/axis2/jaxws/handler/soap/LoggingHandler.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/test/org/apache/axis2/jaxws/handler/soap/LoggingHandler.java?rev=233000&r1=232999&r2=233000&view=diff
==============================================================================
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/test/org/apache/axis2/jaxws/handler/soap/LoggingHandler.java (original)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/test/org/apache/axis2/jaxws/handler/soap/LoggingHandler.java Tue Aug 16 07:32:44 2005
@@ -5,13 +5,13 @@
 import java.util.Set;
 
 import javax.xml.namespace.QName;
-import javax.xml.rpc.JAXRPCException;
-import javax.xml.rpc.ProtocolException;
-import javax.xml.rpc.handler.HandlerInfo;
-import javax.xml.rpc.handler.MessageContext;
-import javax.xml.rpc.handler.soap.SOAPHandler;
-import javax.xml.rpc.handler.soap.SOAPMessageContext;
 import javax.xml.soap.SOAPMessage;
+import javax.xml.ws.WebServiceException;
+import javax.xml.ws.ProtocolException;
+import javax.xml.ws.handler.HandlerInfo;
+import javax.xml.ws.handler.MessageContext;
+import javax.xml.ws.handler.soap.SOAPHandler;
+import javax.xml.ws.handler.soap.SOAPMessageContext;
 
 public class LoggingHandler implements SOAPHandler<SOAPMessageContext> {
 
@@ -41,11 +41,11 @@
 		//Nothing to clean up
 	}
 
-	public void init(HandlerInfo config) throws JAXRPCException {
+	public void init(HandlerInfo config) throws WebServiceException {
 		this.config = config.getHandlerConfig();
 	}
 
-	public void destroy() throws JAXRPCException {
+	public void destroy() throws WebServiceException {
 		//nothing to clean up
 	}
 	

Modified: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/test/org/apache/axis2/jaxws/integrationTesting/ClientAPITest1.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/test/org/apache/axis2/jaxws/integrationTesting/ClientAPITest1.java?rev=233000&r1=232999&r2=233000&view=diff
==============================================================================
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/test/org/apache/axis2/jaxws/integrationTesting/ClientAPITest1.java (original)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/test/org/apache/axis2/jaxws/integrationTesting/ClientAPITest1.java Tue Aug 16 07:32:44 2005
@@ -4,10 +4,11 @@
 
 import javax.xml.namespace.QName;
 import java.net.URL;
-import javax.xml.rpc.ServiceFactory;
-import javax.xml.rpc.Service;
-import javax.xml.rpc.Call;
-import javax.xml.rpc.ParameterMode;
+
+import javax.xml.ws.Call;
+import javax.xml.ws.ParameterMode;
+import javax.xml.ws.Service;
+import javax.xml.ws.ServiceFactory;
 
 public class ClientAPITest1 extends TestCase {
 

Modified: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/test/org/apache/axis2/jaxws/server/ServerTestingPurposeClient.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/test/org/apache/axis2/jaxws/server/ServerTestingPurposeClient.java?rev=233000&r1=232999&r2=233000&view=diff
==============================================================================
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/test/org/apache/axis2/jaxws/server/ServerTestingPurposeClient.java (original)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/test/org/apache/axis2/jaxws/server/ServerTestingPurposeClient.java Tue Aug 16 07:32:44 2005
@@ -8,9 +8,9 @@
 import java.io.FileOutputStream;
 
 import javax.xml.namespace.QName;
-import javax.xml.rpc.Call;
-import javax.xml.rpc.Service;
-import javax.xml.rpc.ParameterMode;
+import javax.xml.ws.Call;
+import javax.xml.ws.ParameterMode;
+import javax.xml.ws.Service;
 //import javax.xml.rpc.ServiceFactory;
 
 import org.apache.axis2.jaxws.client.ServiceImpl;
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/client/CallImpl.java (original)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/client/CallImpl.java Tue Aug 16 07:32:44 2005
@@ -27,11 +27,11 @@
 
 import javax.wsdl.Operation;
 import javax.xml.namespace.QName;
-import javax.xml.rpc.Binding;
-import javax.xml.rpc.JAXRPCContext;
-import javax.xml.rpc.JAXRPCException;
-import javax.xml.rpc.ParameterMode;
-import javax.xml.rpc.soap.SOAPFaultException;
+import javax.xml.ws.Binding;
+import javax.xml.ws.JAXRPCContext;
+import javax.xml.ws.WebServiceException;
+import javax.xml.ws.ParameterMode;
+import javax.xml.ws.soap.SOAPFaultException;
 
 import org.apache.axis2.jaxws.description.ParameterDesc;
 
@@ -53,7 +53,7 @@
  * Forget not that Call instance is MUTABLE. i.e. the configuration of call
  * instance can be changed and it can be re-used for some other need.
  */
-public class CallImpl extends BindingProviderImpl implements javax.xml.rpc.Call {
+public class CallImpl extends BindingProviderImpl implements javax.xml.ws.Call {
 
 	/**
 	 * Field targetEndpointAddress
@@ -171,18 +171,18 @@
 	 * @param xmlType XML type of the parameter
 	 * @param parameterMode Mode of the parameter-whether ParameterMode.IN, 
 	 * ParameterMode.OUT, or ParameterMode.INOUT
 	 * @throws javax.xml.rpc.JAXRPCException This exception may be thrown if 
 	 * the method isParameterAndReturnSpecRequired returns false for this 
 	 * operation.
 	 * @throws java.lang.IllegalArgumentException If any illegal parameter 
 	 * name or XML type is specified
 	 */
 	public void addParameter(String paramName, QName xmlType,
-			ParameterMode parameterMode) throws JAXRPCException,
+			ParameterMode parameterMode) throws WebServiceException,
 			IllegalArgumentException {
 		
 		if(isParameterAndReturnSpecRequired(this.operationName)==false) {
-			throw new JAXRPCException("This operation is configured not to " +
+			throw new WebServiceException("This operation is configured not to " +
 					"specify parameter and return type information ");
 		}
 		
@@ -229,7 +229,7 @@
 	 * name or XML type is specified 
 	 * @throws java.lang.UnsupportedOperationException If this method is not 
 	 * supported
-	 * @throws javax.xml.rpc.JAXRPCException 
+	 * @throws javax.xml.ws.WebServiceException 
 	 * 1.This exception may be thrown if this method is invoked when the 
 	 * method isParameterAndReturnSpecRequired returns false.
 	 * 2.If specified XML type and Java type mapping is not valid. For 
@@ -237,10 +237,10 @@
 	 */
 	public void addParameter(String paramName, QName xmlType, Class javaType,
 			ParameterMode parameterMode) throws IllegalArgumentException,
-			UnsupportedOperationException, JAXRPCException {
+			UnsupportedOperationException, WebServiceException {
 
 		if(isParameterAndReturnSpecRequired(this.operationName)==false) {
-			throw new JAXRPCException("This operation is configured not to " +
+			throw new WebServiceException("This operation is configured not to " +
 					"specify parameter and return type information ");
 		}
 		
@@ -292,19 +292,19 @@
 	 * Sets the return type for a specific operation. Invoking 
 	 * setReturnType(null) removes the return type for this Call object. 
 	 * @param xmlType XML data type of the return value
 	 * @throws javax.xml.rpc.JAXRPCException This exception may be thrown when 
 	 * the method isParameterAndReturnSpecRequired returns false. 
 	 * @throws java.lang.IllegalArgumentException If an illegal XML type is 
 	 * specified 
 	 */
-	public void setReturnType(QName xmlType) throws JAXRPCException,
+	public void setReturnType(QName xmlType) throws WebServiceException,
 			IllegalArgumentException, UnsupportedOperationException {
 		if(operationName==null) {
-			throw new JAXRPCException("Can't set returnType. Try setting the " +
+			throw new WebServiceException("Can't set returnType. Try setting the " +
 					"operationName prior to calling setReturnType");
 		}
 		if(isParameterAndReturnSpecRequired(operationName)==false) {
-			throw new JAXRPCException("Call instance is configured not to " +
+			throw new WebServiceException("Call instance is configured not to " +
 					"specify Parameter and ReturnType");
 		}
 		
@@ -347,7 +347,7 @@
 	 * supported 
 	 * @throws java.lang.IllegalArgumentException If an illegal XML type is 
 	 * specified
-	 * @throws javax.xml.rpc.JAXRPCException
+	 * @throws javax.xml.ws.WebServiceException
 	 * 1. This exception may be thrown if this method is invoked when the 
 	 * method isParameterAndReturnSpecRequired returns false.
 	 * 2. If XML type and Java type cannot be mapped using the standard type 
@@ -355,13 +355,13 @@
 	 */
 	public void setReturnType(QName xmlType, Class javaType)
 			throws UnsupportedOperationException, IllegalArgumentException,
-			JAXRPCException {
+			WebServiceException {
 		if(operationName==null) {
-			throw new JAXRPCException("Can't set returnType. Try setting the " +
+			throw new WebServiceException("Can't set returnType. Try setting the " +
 					"operationName prior to calling setReturnType");
 		}
 		if(isParameterAndReturnSpecRequired(operationName)==false) {
-			throw new JAXRPCException("Call instance is configured not to " +
+			throw new WebServiceException("Call instance is configured not to " +
 					"specify Parameter and ReturnType");
 		}
 		
@@ -377,7 +377,7 @@
 				this.returnTypeClass = javaType;
 			}
 			else
-				throw new JAXRPCException("Set return type java class can't be cast " +
+				throw new WebServiceException("Set return type java class can't be cast " +
 						"from underlying JAXB databinding object");
 		}
 		else {//no JAXB.
@@ -386,7 +386,7 @@
 			if(!service.getTypeMappingRegistry().
 					getTypeMapping(ENCODINGSTYLE_URI_PROPERTY).
 					isRegistered(javaType,xmlType))
-				throw new JAXRPCException("Invalid javaType for xmlType. " +
+				throw new WebServiceException("Invalid javaType for xmlType. " +
 						"Underlying type mapping has no corresponding pair registered");
 		}
 	}
@@ -406,11 +406,11 @@
 	 * Removes all specified parameters from this Call instance. Note that 
 	 * this method removes only the parameters and not the return type. The 
 	 * setReturnType(null) is used to remove the return type.
 	 * @throws javax.xml.rpc.JAXRPCException This exception may be thrown If 
 	 * this method is called when the method isParameterAndReturnSpecRequired 
 	 * returns false for this Call's operation.
 	 */
-	public void removeAllParameters() throws JAXRPCException {
+	public void removeAllParameters() throws WebServiceException {
 		inputParams.clear();
 		outputParams.clear();
 	}
@@ -492,7 +492,7 @@
 	 * method.
 	 * @param name Name of the property
 	 * @param value Value of the property
-	 * @throws javax.xml.rpc.JAXRPCException
+	 * @throws javax.xml.ws.WebServiceException
 	 * 1. If an optional standard property name is specified, however this 
 	 * Call implementation class does not support the configuration of this 
 	 * property.
@@ -500,7 +500,7 @@
 	 * value of mismatched property type is passed.
 	 * 3. If there is any error in the configuration of a valid property.
 	 */
-	public void setProperty(String name, Object value) throws JAXRPCException {
+	public void setProperty(String name, Object value) throws WebServiceException {
 		// TODO Auto-generated method stub
 		
 		//Here a long if-elseif...-else list of construct will come, checking
@@ -530,7 +530,7 @@
 		}else {
 			//we may chose to ignore and add that into the bag or throw
 			//a JAXRPCException. I'm good at the later choice :-)
-			throw new JAXRPCException("Property " + name +" not supported");
+			throw new WebServiceException("Property " + name +" not supported");
 		}
 
 	}
@@ -540,7 +540,7 @@
 	 * Gets the value of a named property. 
 	 * @param name Name of the property
 	 * @return Value of the named property
 	 * @throws javax.xml.rpc.JAXRPCException if an invalid or unsupported 
 	 * property name is passed.
 	 */
 	public Object getProperty(String name) {
@@ -551,7 +551,7 @@
 	 * Method removeProperty
 	 * Removes a named property.
 	 * @param name Name of the property
 	 * @throws javax.xml.rpc.JAXRPCException if an invalid or unsupported 
 	 * property name is passed.
 	 */
 	public void removeProperty(String name) {
@@ -579,15 +579,15 @@
 	 * @return Returns the return value or null
 	 * @throws java.rmi.RemoteException if there is any error in the remote 
 	 * method invocation
 	 * @throws javax.xml.rpc.soap.SOAPFaultException Indicates a SOAP fault
 	 * @throws javax.xml.rpc.JAXRPCException 
 	 * 1. If there is an error in the configuration of the Call object
 	 * 2. If inputParams do not match the required parameter set (as specified
 	 *    through the addParameter invocations or in the corresponding WSDL)
 	 * 3. If parameters and return type are incorrectly specified 
 	 */
 	public Object invoke(Object[] inputParameters) throws RemoteException,
-			SOAPFaultException, JAXRPCException {
+			SOAPFaultException, WebServiceException {
 
 		//check if the call instance is properly configured. If not throw
 		//a JAXRPCException.
@@ -612,7 +612,7 @@
 		}
 		
 		if(throwJAXRPCException) {
-			throw new JAXRPCException("Call instance not fully configured");
+			throw new WebServiceException("Call instance not fully configured");
 		}
 		
 		//I'll try to create an OMElement that would wrap the input params
@@ -696,8 +696,8 @@
 	 * @return Returns the return value or null
 	 * @throws java.rmi.RemoteException if there is any error in the remote 
 	 * method invocation
 	 * @throws javax.xml.rpc.soap.SOAPFaultException Indicates a SOAP fault
 	 * @throws javax.xml.rpc.JAXRPCException 
 	 * 1. If there is an error in the configuration of the Call object
 	 * 2. If inputParams do not match the required parameter set (as specified 
 	 *    through the addParameter invocations or in the corresponding WSDL)
@@ -731,14 +731,14 @@
 	 * Method invokeOneWay
 	 * @param inputParams Object[]--Parameters for this invocation. This 
 	 * includes only the input params.
 	 * @throws javax.xml.rpc.JAXRPCException if there is an error in the 
 	 * configuration of the Call object (example: a non-void return type has 
 	 * been incorrectly specified for the one-way call) or if there is any 
 	 * error during the invocation of the one-way remote call
 	 */
-	public void invokeOneWay(Object[] inputParameters) throws JAXRPCException {
+	public void invokeOneWay(Object[] inputParameters) throws WebServiceException {
 		if(returnType!=null && !returnType.getLocalPart().equals("void")) {
-			throw new JAXRPCException("invokeOneWay should not have a non-void" +
+			throw new WebServiceException("invokeOneWay should not have a non-void" +
 					" return type set.");
 		}
 		try {
@@ -767,7 +767,7 @@
 			axis2Call.invokeNonBlocking(operationName.getLocalPart(),methodElement,callback);
 			
 		}catch(Exception e) {
-			throw new JAXRPCException(e);
+			throw new WebServiceException(e);
 		}
 	}
 
@@ -778,10 +778,10 @@
 	 * java.lang.String.
 	 * @return Map Output parameters for the last Call.invoke(). Empty Map is 
 	 * returned if there are no output parameters.
 	 * @throws JAXRPCException If this method is invoked for a one-way 
 	 * operation or is invoked before any invoke method has been called.
 	 */
-	public Map getOutputParams() throws JAXRPCException {
+	public Map getOutputParams() throws WebServiceException {
 		return (Map)outputParams;
 	}
 
@@ -791,10 +791,10 @@
 	 * operation.
 	 * @return java.util.List Values for the output parameters. An empty List 
 	 * is returned if there are no output values.
 	 * @throws JAXRPCException If this method is invoked for a one-way 
 	 * operation or is invoked before any invoke method has been called.
 	 */
-	public List getOutputValues() throws JAXRPCException {
+	public List getOutputValues() throws WebServiceException {
 		return (List)outputParams.values();
 	}
 
@@ -171,18 +171,18 @@
 	 * @param parameterMode Mode of the parameter-whether ParameterMode.IN, 
 	 * ParameterMode.OUT, or ParameterMode.INOUT
-	 * @throws javax.xml.rpc.JAXRPCException This exception may be thrown if 
+	 * @throws javax.xml.ws.WebServiceException This exception may be thrown if 
 	 * the method isParameterAndReturnSpecRequired returns false for this 
 	 * operation.
@@ -292,19 +292,19 @@
 	 * setReturnType(null) removes the return type for this Call object. 
 	 * @param xmlType XML data type of the return value
-	 * @throws javax.xml.rpc.JAXRPCException This exception may be thrown when 
+	 * @throws javax.xml.ws.WebServiceException This exception may be thrown when 
 	 * the method isParameterAndReturnSpecRequired returns false. 
 	 * @throws java.lang.IllegalArgumentException If an illegal XML type is 
@@ -406,11 +406,11 @@
 	 * this method removes only the parameters and not the return type. The 
 	 * setReturnType(null) is used to remove the return type.
-	 * @throws javax.xml.rpc.JAXRPCException This exception may be thrown If 
+	 * @throws javax.xml.ws.WebServiceException This exception may be thrown If 
 	 * this method is called when the method isParameterAndReturnSpecRequired 
 	 * returns false for this Call's operation.
@@ -540,7 +540,7 @@
 	 * @param name Name of the property
 	 * @return Value of the named property
-	 * @throws javax.xml.rpc.JAXRPCException if an invalid or unsupported 
+	 * @throws javax.xml.ws.WebServiceException if an invalid or unsupported 
 	 * property name is passed.
 	 */
@@ -551,7 +551,7 @@
 	 * Removes a named property.
 	 * @param name Name of the property
-	 * @throws javax.xml.rpc.JAXRPCException if an invalid or unsupported 
+	 * @throws javax.xml.ws.WebServiceException if an invalid or unsupported 
 	 * property name is passed.
 	 */
@@ -579,15 +579,15 @@
 	 * @throws java.rmi.RemoteException if there is any error in the remote 
 	 * method invocation
-	 * @throws javax.xml.rpc.soap.SOAPFaultException Indicates a SOAP fault
-	 * @throws javax.xml.rpc.JAXRPCException 
+	 * @throws javax.xml.ws.soap.SOAPFaultException Indicates a SOAP fault
+	 * @throws javax.xml.ws.WebServiceException 
 	 * 1. If there is an error in the configuration of the Call object
 	 * 2. If inputParams do not match the required parameter set (as specified
@@ -696,8 +696,8 @@
 	 * @throws java.rmi.RemoteException if there is any error in the remote 
 	 * method invocation
-	 * @throws javax.xml.rpc.soap.SOAPFaultException Indicates a SOAP fault
-	 * @throws javax.xml.rpc.JAXRPCException 
+	 * @throws javax.xml.ws.soap.SOAPFaultException Indicates a SOAP fault
+	 * @throws javax.xml.ws.WebServiceException 
 	 * 1. If there is an error in the configuration of the Call object
 	 * 2. If inputParams do not match the required parameter set (as specified 
@@ -731,14 +731,14 @@
 	 * @param inputParams Object[]--Parameters for this invocation. This 
 	 * includes only the input params.
-	 * @throws javax.xml.rpc.JAXRPCException if there is an error in the 
+	 * @throws javax.xml.ws.WebServiceException if there is an error in the 
 	 * configuration of the Call object (example: a non-void return type has 
 	 * been incorrectly specified for the one-way call) or if there is any 
@@ -778,10 +778,10 @@
 	 * @return Map Output parameters for the last Call.invoke(). Empty Map is 
 	 * returned if there are no output parameters.
-	 * @throws JAXRPCException If this method is invoked for a one-way 
+	 * @throws WebServiceException If this method is invoked for a one-way 
 	 * operation or is invoked before any invoke method has been called.
 	 */
@@ -791,10 +791,10 @@
 	 * @return java.util.List Values for the output parameters. An empty List 
 	 * is returned if there are no output values.
-	 * @throws JAXRPCException If this method is invoked for a one-way 
+	 * @throws WebServiceException If this method is invoked for a one-way 
 	 * operation or is invoked before any invoke method has been called.
 	 */

Modified: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/client/DispatchImpl.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/client/DispatchImpl.java?rev=233000&r1=232999&r2=233000&view=diff
==============================================================================
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/client/DispatchImpl.java (original)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/client/DispatchImpl.java Tue Aug 16 07:32:44 2005
@@ -3,10 +3,6 @@
 import java.rmi.RemoteException;
 import java.util.concurrent.Future;
 
-import javax.xml.rpc.AsyncHandler;
-import javax.xml.rpc.Dispatch;
-import javax.xml.rpc.JAXRPCException;
-import javax.xml.rpc.Response;
 
 import org.apache.axis2.addressing.AddressingConstants;
 import org.apache.axis2.addressing.EndpointReference;
@@ -19,6 +15,10 @@
 import javax.xml.stream.XMLStreamException;
 import javax.xml.stream.XMLStreamWriter;
 import javax.xml.transform.Source;
+import javax.xml.ws.AsyncHandler;
+import javax.xml.ws.Dispatch;
+import javax.xml.ws.WebServiceException;
+import javax.xml.ws.Response;
 import javax.xml.namespace.QName;
 
 public class DispatchImpl extends BindingProviderImpl implements Dispatch {
@@ -44,7 +44,7 @@
 	 * invocation.
 	 * @throws java.rmi.RemoteException - If a fault occurs during 
 	 * communication with the service
 	 * @throws JAXRPCException - If there is any error in the configuration 
 	 * of the Dispatch instance. 
 	 */
 	public Object invoke(Object msg) throws RemoteException {
@@ -71,7 +71,7 @@
 			//TODO actually the response message better be transformed to a Source object
 			//and returned.
 		} catch(Exception e) {
-			throw new JAXRPCException(e);
+			throw new WebServiceException(e);
 		}
 		
 		//Implementation (at least a makeshift as above) should happen for the other
@@ -91,10 +91,10 @@
 	 * message used to invoke the operation.
 	 * @return The response message or message payload to the operation 
 	 * invocation.
 	 * @throws JAXRPCException - If there is any error in the configuration 
 	 * of the Dispatch instance.
 	 */
-	public Response invokeAsync(Object msg) throws JAXRPCException {
+	public Response invokeAsync(Object msg) throws WebServiceException {
 		// TODO Auto-generated method stub
 		return null;
 	}
@@ -117,11 +117,11 @@
 	 * the results of the operation - the object returned from Future.get() 
 	 * is implementation dependent and any use of it will result in 
 	 * non-portable behaviour.
 	 * @throws JAXRPCException - If there is any error in the configuration 
 	 * of the Dispatch instance
 	 */
 	public Future invokeAsync(Object msg, AsyncHandler handler)
-			throws JAXRPCException {
+			throws WebServiceException {
 		// TODO Auto-generated method stub
 		return null;
 	}
@@ -138,10 +138,10 @@
 	 * 
 	 * @param msg - An object that will form the message or payload of the 
 	 * message used to invoke the operation.
 	 * @throws JAXRPCException - If there is any error in the configuration 
 	 * of the Dispatch instance or if an error occurs during the invocation.
 	 */
-	public void invokeOneWay(Object msg) throws JAXRPCException {
+	public void invokeOneWay(Object msg) throws WebServiceException {
 		// TODO Auto-generated method stub
 
 	}
@@ -44,7 +44,7 @@
 	 * @throws java.rmi.RemoteException - If a fault occurs during 
 	 * communication with the service
-	 * @throws JAXRPCException - If there is any error in the configuration 
+	 * @throws WebServiceException - If there is any error in the configuration 
 	 * of the Dispatch instance. 
 	 */
@@ -91,10 +91,10 @@
 	 * @return The response message or message payload to the operation 
 	 * invocation.
-	 * @throws JAXRPCException - If there is any error in the configuration 
+	 * @throws WebServiceException - If there is any error in the configuration 
 	 * of the Dispatch instance.
 	 */
@@ -117,11 +117,11 @@
 	 * is implementation dependent and any use of it will result in 
 	 * non-portable behaviour.
-	 * @throws JAXRPCException - If there is any error in the configuration 
+	 * @throws WebServiceException - If there is any error in the configuration 
 	 * of the Dispatch instance
 	 */
@@ -138,10 +138,10 @@
 	 * @param msg - An object that will form the message or payload of the 
 	 * message used to invoke the operation.
-	 * @throws JAXRPCException - If there is any error in the configuration 
+	 * @throws WebServiceException - If there is any error in the configuration 
 	 * of the Dispatch instance or if an error occurs during the invocation.
 	 */

Modified: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/client/JAXRPCContextImpl.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/client/JAXRPCContextImpl.java?rev=233000&r1=232999&r2=233000&view=diff
==============================================================================
--- webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/server/ServletEndpointContextImpl.java (original)
+++ webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/server/ServletEndpointContextImpl.java Tue Aug 16 07:32:44 2005
@@ -4,9 +4,9 @@
 
 import javax.servlet.ServletContext;
 import javax.servlet.http.HttpSession;
-import javax.xml.rpc.JAXRPCException;
-import javax.xml.rpc.handler.MessageContext;
 import javax.xml.rpc.server.ServletEndpointContext;
+import javax.xml.ws.WebServiceException;
+import javax.xml.ws.handler.MessageContext;
 
 
 /**
@@ -75,9 +75,9 @@
 	 * the underlying JAX-RPC runtime system is responsible for managing whether or not there is an active HTTP session.
 	 * 
 	 * @return The HTTP session associated with the current invocation or null if there is no active session.
 	 * @throws JAXRPCException - If this method invoked by any non-HTTP bound endpoint
 	 */
-	public HttpSession getHttpSession() throws JAXRPCException {
+	public HttpSession getHttpSession() throws WebServiceException {
 		return httpSession;
 	}
 
@@ -75,9 +75,9 @@
 	 * 
 	 * @return The HTTP session associated with the current invocation or null if there is no active session.
-	 * @throws JAXRPCException - If this method invoked by any non-HTTP bound endpoint
+	 * @throws WebServiceException - If this method invoked by any non-HTTP bound endpoint
 	 */

Modified: webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/soap/SOAPBindingImpl.java
URL: http://svn.apache.org/viewcvs/webservices/axis/trunk/archive/java/scratch/ashu_jaya_venkat/jaxws/src/org/apache/axis2/jaxws/soap/SOAPBindingImpl.java?rev=233000&r1=232999&r2=233000&view=diff
==============================================================================